@@ -111,7 +111,7 @@ pad_process_relative(struct pad_dispatch *pad,
 		break;
 	case REL_WHEEL:
 		if (!pad->dials.has_hires_dial) {
-			pad->dials.dial1 = e->value * 120;
+			pad->dials.dial1 = -1 * e->value * 120;
 			pad->changed_axes |= PAD_AXIS_DIAL1;
 			pad_set_status(pad, PAD_AXES_UPDATED);
 		}
@@ -124,7 +124,7 @@ pad_process_relative(struct pad_dispatch *pad,
 		}
 		break;
 	case REL_WHEEL_HI_RES:
-		pad->dials.dial1 = e->value;
+		pad->dials.dial1 = -1 * e->value;
 		pad->changed_axes |= PAD_AXIS_DIAL1;
 		pad_set_status(pad, PAD_AXES_UPDATED);
 		break;
